/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2000
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Vidur Apparao <vidur@netscape.com> (original author)
 *   Johnny Stenback <jst@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIDOMElement.idl"

interface nsIDOMDOMStringMap;
interface nsIDOMHTMLMenuElement;

/**
 * The nsIDOMHTMLElement interface is the primary [X]HTML element
 * interface. It represents a single [X]HTML element in the document
 * tree.
 *
 * This interface is trying to follow the DOM Level 2 HTML specification:
 * http://www.w3.org/TR/DOM-Level-2-HTML/
 *
 * with changes from the work-in-progress WHATWG HTML specification:
 * http://www.whatwg.org/specs/web-apps/current-work/
 */
[scriptable, uuid(0a21bb68-d8bd-4b2a-a3db-048a02e81c62)]
interface nsIDOMHTMLElement : nsIDOMElement
{
  // metadata attributes
           attribute DOMString        id;
           attribute DOMString        title;
           attribute DOMString        lang;
           attribute DOMString        dir;
           attribute DOMString        className;
  readonly attribute nsIDOMDOMStringMap dataset;

  // user interaction
  /**
   * Indicates that the element is not yet, or is no longer, relevant.
   *
   * See <http://www.whatwg.org/html5/#the-hidden-attribute>.
   */
           attribute boolean          hidden;
  void click();
           attribute long             tabIndex;
  void focus();
  void blur();
           attribute DOMString        accessKey;
  readonly attribute DOMString        accessKeyLabel;
           attribute boolean          draggable;
           attribute DOMString        contentEditable;
  readonly attribute boolean          isContentEditable;
  readonly attribute nsIDOMHTMLMenuElement contextMenu;
           attribute boolean          spellcheck;


  // DOM Parsing and Serialization
           attribute DOMString        innerHTML;
  void insertAdjacentHTML(in DOMString position,
                          in DOMString text);


  // CSSOM View
  [optional_argc] void scrollIntoView([optional] in boolean top);
  readonly attribute nsIDOMElement    offsetParent;
  readonly attribute long             offsetTop;
  readonly attribute long             offsetLeft;
  readonly attribute long             offsetWidth;
  readonly attribute long             offsetHeight;


  // Mozilla extensions
  /**
   * Requests that this element be made the full-screen element, as per the DOM
   * full-screen api.
   *
   * @see <https://wiki.mozilla.org/index.php?title=Gecko:FullScreenAPI>
   */
  void mozRequestFullScreen();  
};
