/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 * vim: sw=2 ts=2 et :
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Plugins.
 *
 * The Initial Developer of the Original Code is
 *   Mozilla Foundation.
 * Portions created by the Initial Developer are Copyright (C) 2010
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Ben Turner <bent.mozilla@gmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef dom_plugins_PluginIdentifierParent_h
#define dom_plugins_PluginIdentifierParent_h

#include "mozilla/plugins/PPluginIdentifierParent.h"

#include "npapi.h"
#include "npruntime.h"

namespace mozilla {
namespace plugins {

class PluginInstanceParent;

class PluginIdentifierParent : public PPluginIdentifierParent
{
  friend class PluginModuleParent;

public:
  NPIdentifier ToNPIdentifier()
  {
    return mIdentifier;
  }

  bool IsTemporary() {
    return !!mTemporaryRefs;
  }

  /**
   * Holds a perhaps-temporary identifier for the current stack frame.
   */
  class NS_STACK_CLASS StackIdentifier
  {
  public:
    StackIdentifier(PluginInstanceParent* inst, NPIdentifier aIdentifier);
    StackIdentifier(NPObject* aObject, NPIdentifier aIdentifier);
    ~StackIdentifier();

    operator PluginIdentifierParent*() {
      return mIdentifier;
    }

  private:
    DISALLOW_COPY_AND_ASSIGN(StackIdentifier);

    PluginIdentifierParent* mIdentifier;
  };

protected:
  PluginIdentifierParent(NPIdentifier aIdentifier, bool aTemporary)
    : mIdentifier(aIdentifier)
    , mTemporaryRefs(aTemporary ? 1 : 0)
  {
    MOZ_COUNT_CTOR(PluginIdentifierParent);
  }

  virtual ~PluginIdentifierParent()
  {
    MOZ_COUNT_DTOR(PluginIdentifierParent);
  }

  virtual bool RecvRetain();

  void AddTemporaryRef() {
    mTemporaryRefs++;
  }

  /**
   * @returns true if the last temporary reference was removed.
   */
  bool RemoveTemporaryRef() {
    --mTemporaryRefs;
    return !mTemporaryRefs;
  }

private:
  NPIdentifier mIdentifier;
  unsigned int mTemporaryRefs;
};

} // namespace plugins
} // namespace mozilla

#endif // dom_plugins_PluginIdentifierParent_h
